summaryrefslogtreecommitdiff
path: root/src/mongo/db/fts/fts_index_format.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/fts/fts_index_format.h')
-rw-r--r--src/mongo/db/fts/fts_index_format.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/mongo/db/fts/fts_index_format.h b/src/mongo/db/fts/fts_index_format.h
index e7d64bc0479..75084e822ad 100644
--- a/src/mongo/db/fts/fts_index_format.h
+++ b/src/mongo/db/fts/fts_index_format.h
@@ -46,12 +46,12 @@ namespace mongo {
/*
* Helper method to get return entry from the FTSIndex as a BSONObj
* @param weight, the weight of the term in the entry
* @param term, the string term in the entry
* @param indexPrefix, the fields that go in the index first
* @param textIndexVersion, index version. affects key format.
*/
static BSONObj getIndexKey( double weight,
- const string& term,
+ const std::string& term,
const BSONObj& indexPrefix,
TextIndexVersion textIndexVersion );
@@ -60,10 +60,10 @@ namespace mongo {
* Helper method to get return entry from the FTSIndex as a BSONObj
* @param b, reference to the BSONOBjBuilder
* @param weight, the weight of the term in the entry
* @param term, the string term in the entry
* @param textIndexVersion, index version. affects key format.
*/
- static void _appendIndexKey( BSONObjBuilder& b, double weight, const string& term,
+ static void _appendIndexKey( BSONObjBuilder& b, double weight, const std::string& term,
TextIndexVersion textIndexVersion );
};
@@ -46,12 +46,12 @@ namespace mongo {
* Helper method to get return entry from the FTSIndex as a BSONObj
* @param weight, the weight of the term in the entry
- * @param term, the string term in the entry
+ * @param term, the std::string term in the entry
* @param indexPrefix, the fields that go in the index first
* @param textIndexVersion, index version. affects key format.
@@ -60,10 +60,10 @@ namespace mongo {
* @param b, reference to the BSONOBjBuilder
* @param weight, the weight of the term in the entry
- * @param term, the string term in the entry
+ * @param term, the std::string term in the entry
* @param textIndexVersion, index version. affects key format.
*/